import { AgentContext } from '../../agent';
import { Key } from '../Key';
import { ExtensionInput, X509Certificate } from './X509Certificate';
export declare class X509Service {
    /**
     *
     * Validate a chain of X.509 certificates according to RFC 5280
     *
     * This function requires a list of base64 encoded certificates and, optionally, a certificate that should be found in the chain.
     * If no certificate is provided, it will just assume the leaf certificate
     *
     * The leaf certificate should be the 0th index and the root the last
     *
     * Note:
     *   - Does not check whether a root or intermediate certificate is trusted
     *
     * Additional validation:
     *   - Make sure atleast a single certificate is in the chain
     */
    static validateCertificateChain(agentContext: AgentContext, { certificateChain, certificate, date, }: {
        certificateChain: Array<string>;
        certificate?: string;
        date?: Date;
    }): Promise<X509Certificate[]>;
    /**
     *
     * Parses a base64-encoded X.509 certificate into a {@link X509Certificate}
     *
     */
    static parseCertificate(_agentContext: AgentContext, { encodedCertificate }: {
        encodedCertificate: string;
    }): X509Certificate;
    static getLeafCertificate(_agentContext: AgentContext, { certificateChain }: {
        certificateChain: Array<string>;
    }): X509Certificate;
    static createSelfSignedCertificate(agentContext: AgentContext, options: {
        key: Key;
        extensions?: ExtensionInput;
        notBefore?: Date;
        notAfter?: Date;
        name?: string;
    }): Promise<X509Certificate>;
}
